import { performance} from'perf_hooks'
const {now} = performance

import {
  createWorld,
  registerComponent,
  registerComponents,
  defineComponent,
  defineQuery,
  Changed,
  Not,
  enterQuery,
  exitQuery,
  defineSystem,
  addComponent,
  removeComponent,
  addEntity,
  removeEntity,
  defineSerializer,
  defineDeserializer,
  commitRemovals,
  Types,
} from './src/index.js'

const world = createWorld()

const { f32 } = Types
const Vector2 = { x: f32, y: f32 }
const Position = defineComponent(Vector2)
const Velocity = defineComponent(Vector2)
// registerComponents(world, [Position, Velocity])

const query = defineQuery([Position,Velocity])
const serialize = defineSerializer([Position, Velocity])
const deserialize = defineDeserializer([Position,Velocity])

const notPosition = defineQuery([Not(Position)])

const n = 500_000
for (let i = 0; i < n; i++) {
  const eid = addEntity(world)
  addComponent(world, Position, eid)
  addComponent(world, Velocity, eid)
  Position.x[eid]++
  Position.y[eid]++
  Velocity.x[eid]++
  Velocity.y[eid]++
}

// removeComponent(world, Position, 0)
// console.log(query(world))

// removeEntity(world, 1)

// console.log(query(world).length)


// console.log(notPosition(world))

let then

console.log(`n = ${n}`)

then = now()
const ents = query(world)
console.log('query', (now()-then).toFixed(2))

then = now()
const packet = serialize(ents)
console.log('serialize', (now()-then).toFixed(2))

then = now()
deserialize(packet)
console.log('deserialize', (now()-then).toFixed(2))

